from earthdiagnostics import Utils, TempFile, cdftools
import shutil
import os

class General(object):

    @staticmethod
    def vertical_mean(input_file, output_file, variable, lev_min, lev_max):
        """
        Choose vertical level in ocean, or vertically average between
        2 or more  ocean levels

        Created in  February 2012      Author : vguemas@ic3.cat
        Modified (more generic, i.e. for any input var) in December 2014
        Author : eleftheria.exarchou@ic3.cat

        :param input_file: input file name
        :param output_file: output file name  (=> 2D field  )
        :param variable: variable name
        :param lev_min: upper depth of the layer (in level number)
        :param lev_max: lower depth of the layer (in level number. If same as the upper layer, then the script just
        selects this layer. If its different, a vertical integral (weighted) between upper and lower level is computed
        """

        temp = TempFile.get()
        temp2 = TempFile.get()

        shutil.copy(input_file, temp)

        handler = Utils.nco.openCdf(temp)
        lev_min = handler.variables['lev'][lev_min]
        lev_max = handler.variables['lev'][lev_max]

        cdftools.run('cdfvertmean', input=temp, output=temp2, options=[variable, 'T', lev_min, lev_max,
                                                                       '-full', '-debug'])
        os.remove(temp)
        Utils.setminmax(temp2, '{0}_vert_mean'.format(variable))
        Utils.rename_variable(temp2, '{0}_vert_mean'.format(variable), '{0}mean{1}-{2}'.format(variable, lev_min, lev_max))
        Utils.move_file(temp2, output_file)